@@ -1,6 +1,7 @@
 # Purpose : Provide a common interface to a variety of rendering formats
 # Author  : Matt Wilson - Original version by John Alden
 # Created : March 2006
+# CVS     : $Header: /home/cvs/software/cvsroot/any_renderer/lib/Any/Renderer.pm,v 1.14 2006/09/04 12:15:52 johna Exp $
 
 package Any::Renderer;
 
@@ -9,7 +10,7 @@ use File::Find;
 use File::Spec;
 
 use vars qw($VERSION %Formats @LowPriProviders);
-$VERSION = '1.015_02';
+$VERSION = sprintf"%d.%03d", q$Revision: 1.14 $ =~ /: (\d+)\.(\d+)/;
 
 #Modules that provide an extensible set of formats that could clash with A::R native providers
 @LowPriProviders = qw(Data::Serializer);
@@ -119,11 +120,7 @@ sub available_formats
 			$module = _load_module($file);     
 			$func = $module->can( "available_formats" );
 		};
-                {
-                    no warnings;
-                    no strict 'refs';
-                    ${__PACKAGE__."::_FailedBackends"}{backend}{$file} = $@ if($@);
-                }
+		warn($@) if($@); #Warn if there are compilation problems with backend modules
 		
 		next unless $func;
 		
@@ -140,24 +137,6 @@ sub available_formats
 	return [ sort keys %Formats ];
 }
 
-
-sub failed_backends {
-    available_formats();
-    no warnings;
-    no strict 'refs';
-    my @failed_backends = keys %{${__PACKAGE__."::_FailedBackends"}{backend}};
-    \@failed_backends;
-}
-
-
-sub failed_backend_message {
-    my $file = shift;
-    no warnings;
-    no strict 'refs';
-    ${__PACKAGE__."::_FailedBackends"}{backend}{$file}; 
-}
-
-
 #Loads an Any::Renderer backend (safely)
 sub _load_module {
 	my $file = shift; 
@@ -187,8 +166,6 @@ Any::Renderer - Common API for modules that convert data structures into strings
 	$string = $renderer->render ( $structure );
 	$bool = Any::Renderer::requires_template ( $format );
 	$list_ref = Any::Renderer::available_formats ();
-        $list_ref = Any::Renderer::failed_backends ();
-        $string = Any::Renderer::failed_backend_message($backend_name);
 
 =head1 DESCRIPTION
 
@@ -237,21 +214,8 @@ template than 1 will be returned, otherwise 0.
 Discover a list of all known rendering formats that the backend modules
 provide, e.g. ( 'HTML::Template', 'JavaScript' [, ...]).
 
-
-=item $list_ref = Any::Renderer::failed_backends()
-
-Retuns all backends that failed to load
-
-
-
-=item $message = Any::Renderer::failed_backend_message($backend)
-
-Return the error message for a backend
-
 =back
 
-
-
 =head1 GLOBAL VARIABLES
 
 =over 4
@@ -328,11 +292,13 @@ All the serializers supported by Data::Serializer are automatically available vi
 
 =back
 	
+=head1 VERSION
+
+$Revision: 1.14 $ on $Date: 2006/09/04 12:15:52 $ by $Author: johna $
+
 =head1 AUTHOR
 
-Current: Kevin McGrath  
-
-Pre-v1.015 Matt Wilson (original version by John Alden) <cpan _at_ bbc _dot_ co _dot_ uk>
+Matt Wilson (original version by John Alden) <cpan _at_ bbc _dot_ co _dot_ uk>
 
 =head1 COPYRIGHT
 
